/*******************************************************************************
 * Portions created by Sebastian Thomschke are copyright (c) 2006 Sebastian
 * Thomschke.
 * 
 * All Rights Reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Sebastian Thomschke - initial implementation.
 *******************************************************************************/
package net.sf.oval;

import java.lang.reflect.AccessibleObject;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;
import java.util.WeakHashMap;

import net.sf.oval.exceptions.ReflectionException;

/**
 * This implementation determines the names of constructor and method parameters by simply enumerating them based on there index
 *  
 * @author Sebastian Thomschke
 */
public class ParameterNameResolverEnumerationImpl implements ParameterNameResolver
{
	private final WeakHashMap<AccessibleObject, String[]> parameterNamesCache = new WeakHashMap<AccessibleObject, String[]>();

	public String[] getParameterNames(final Method method) throws ReflectionException
	{
		/*
		 * intentionally the following code is not synchronized
		 */
		String[] parameterNames = parameterNamesCache.get(method);
		if (parameterNames == null)
		{
			final int parameterCount = method.getParameterTypes().length;
			parameterNames = new String[parameterCount];
			for (int i = 0; i < parameterCount; i++)
			{
				parameterNames[i] = "parameter" + i;
			}
			parameterNamesCache.put(method, parameterNames);
		}
		return parameterNames;
	}

	public String[] getParameterNames(final Constructor constructor) throws ReflectionException
	{
		/*
		 * intentionally the following code is not synchronized
		 */
		String[] parameterNames = parameterNamesCache.get(constructor);
		if (parameterNames == null)
		{
			final int parameterCount = constructor.getParameterTypes().length;
			parameterNames = new String[parameterCount];
			for (int i = 0; i < parameterCount; i++)
			{
				parameterNames[i] = "parameter" + i;
			}
			parameterNamesCache.put(constructor, parameterNames);
		}
		return parameterNames;
	}
}
